################################################################################
# DNA methylation analysis with RnBeads
# Epigenomics 2016 Workshop
# ------------------------------------------------------------------------------
#  Improving RnBeads' performance
# ------------------------------------------------------------------------------
# ------------------------------------------------------------------------------
# created: 2016-01-15
# author:  Fabian Mueller <rnbeads@mpi-inf.mpg.de>
# http://rnbeads.mpi-inf.mpg.de/
################################################################################

################################################################################
# (0) Preliminaries
################################################################################
# load the package
library(RnBeads)

# define the directory structure
# setwd(".")
resultDir <- file.path(getwd(), "results")

################################################################################
# (1) Parallel computing
################################################################################
parallel.isEnabled()
num.cores <- 2
# enable parallel computation for critical steps in the analysis
# in the back, RnBeads uses the "foreach" and "doParallel" packages
parallel.setup(num.cores)

parallel.isEnabled()
parallel.getNumWorkers()

# disable parallel computation again
parallel.teardown()
parallel.isEnabled()

################################################################################
# (2) Disk-based storage of large data matrices
################################################################################
# RnBeads by default stores large matrices on disk rather than in main memory
# in order to reduce resource requirements
# the "ff" package is used for this
rnb.getOption("disk.dump.big.matrices")
# rnb.options(disk.dump.big.matrices=TRUE)

# configure where the matrices are stored (default: temporary directory)
getOption("fftempdir")
largeMatrixDir <- file.path(resultDir, "large_matrices")
options(fftempdir=largeMatrixDir)

################################################################################
# (3) RnBeads in a scientific compute cluster environment
################################################################################
# see vignette
